﻿<#
.SYNOPSIS
	Installs updates for the local machine (needs admin rights)
.DESCRIPTION
	install-updates.ps1
.EXAMPLE
	PS> ./install-updates
.NOTES
	Author: Markus Fleschutz · License: CC0
.LINK
	https://github.com/fleschutz/PowerShell
#>

#Requires -RunAsAdministrator

try {
	$StopWatch = [system.diagnostics.stopwatch]::startNew()

	if ($IsLinux) {
		"⏳ Step 1/4: Fetching update infos for installed Debian packages..."
		& sudo apt update

		"⏳ Step 2/4: Upgrading installed Debian packages..."
		& sudo apt upgrade --yes

		"⏳ Step 3/4: Removing obsolete Debian packages..."
		& sudo apt autoremove --yes

		"⏳ Step 4/4: Upgrading installed Snap packages..."
		& sudo snap refresh
	} else {
		"Sorry, not supported yet"
	}

	[int]$Elapsed = $StopWatch.Elapsed.TotalSeconds
	"✔️ installed updates in $Elapsed sec"
	exit 0 # success
} catch {
	"⚠️ Error: $($Error[0]) ($($MyInvocation.MyCommand.Name):$($_.InvocationInfo.ScriptLineNumber))"
	exit 1
}
