﻿<#
.SYNOPSIS
	Lists the exchange rates for a currency
.DESCRIPTION
	Lists the current exchange rates for the given currency (USD per default).
	list-exchange-rates.ps1 [<currency>]
.EXAMPLE
	PS> ./list-exchange-rates EUR
.NOTES
	Author: Markus Fleschutz · License: CC0
.LINK
	https://github.com/fleschutz/PowerShell
#>

param([string]$currency = "USD")

function ListExchangeRates { param([string]$currency)
	[xml]$ExchangeRates = (invoke-webRequest -uri "http://www.floatrates.com/daily/$($currency).xml" -userAgent "curl" -useBasicParsing).Content 
	foreach($Row in $ExchangeRates.channel.item) {
		new-object PSObject -property @{ 'Rate' = "$($Row.exchangeRate)"; 'Currency' = "$($Row.targetCurrency) - $($Row.targetName)"; 'Inverse' = "$($Row.inverseRate)"; 'Date' = "$($Row.pubDate)" }
	}
}

try {
	""
	"Current Exchange Rates for 1 $currency (source: http://www.floatrates.com)"
	"================================"

	ListExchangeRates $currency | format-table -property Rate,Currency,Inverse,Date
	exit 0 # success
} catch {
	"⚠️ Error: $($Error[0]) ($($MyInvocation.MyCommand.Name):$($_.InvocationInfo.ScriptLineNumber))"
	exit 1
}
